# cm-rgb
[![Version](https://img.shields.io/pypi/v/cm-rgb?style=for-the-badge)](https://pypi.org/project/cm-rgb/)
[![Licence](https://img.shields.io/github/license/gfduszynski/cm-rgb?color=blue&style=for-the-badge)](https://github.com/gfduszynski/cm-rgb/)
[![Downloads](https://img.shields.io/pypi/dm/cm-rgb?&style=for-the-badge)](https://github.com/gfduszynski/cm-rgb/)
[![PayPal](https://img.shields.io/badge/PayPal-3$-1abc9c.svg?style=for-the-badge)](https://www.paypal.me/gfduszynski/3USD)


### Control your Wraith Prism RGB on Linux, Mac OS and Windows

![Picutre](https://github.com/gfduszynski/cm-rgb/raw/master/cm-rgb-monitor.gif)

**cm-rgb-monitor** _showing realtime cpu utilization._


## Getting started
### Installation & Configuration

Follow [this simple guide on our wiki.](https://github.com/gfduszynski/cm-rgb/wiki/1.-Installation-&-Configuration)

### Usage

Package comes with two scripts ``cm-rgb-cli`` and ``cm-rgb-monitor``.  

``cm-rgb-cli`` allows for fine grained control of each individual zone including [turning off the LED's](https://github.com/gfduszynski/cm-rgb/wiki/2.-CLI-usage#3-turning-all-zones-off) completely.

Check out the [examples in our wiki](https://github.com/gfduszynski/cm-rgb/wiki/2.-CLI-usage).


![Picture](https://github.com/groovykiwi/cm-rgb-gui/raw/master/gui-ss.png)
``cm-rgb-gui`` GUI interface that serves the purpose of simplifying the usage of [cm-rgb-cli] (thanks to [groovykiwi](https://github.com/groovykiwi))

``cm-rgb-monitor`` allows for displaying cpu utilization with ring LED's, along with temperature (thanks to [mpsdskd](https://github.com/mpsdskd)).

Combining the cli + monitor can create neat transition from powering your system right to booting your OS.

Check out the [examples in our wiki](https://github.com/gfduszynski/cm-rgb/wiki/3.-Monitor-usage).

## Licence

**MIT** 

See LICENCE file for details